module.exports = defineTest({
	description: 'shorthand properties referencing deshadowed variables are expanded'
});
